@@ -87,9 +87,8 @@ int main(int argc, char **argv)
 
     bt::SetClientInfo(QStringLiteral("KTorrent"), kt::MAJOR, kt::MINOR, kt::RELEASE, kt::VERSION_TYPE, QStringLiteral("KT"));
 
-    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
-    KLocalizedString::setApplicationDomain("ktorrent");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("ktorrent"));
 
     QApplication app(argc, argv);
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("ktorrent")));
@@ -125,10 +124,13 @@ int main(int argc, char **argv)
     about.addCredit(i18n("Felix Berger"), i18n("ChunkBar's tooltip and IWFileTreeItem sorting"), QStringLiteral("bflat1@gmx.net"));
     about.addCredit(i18n("Andreas Kling"), QString(), QStringLiteral("kling@impul.se"));
     about.addCredit(i18n("Felipe Sateler"), QString(), QStringLiteral("fsateler@gmail.com"));
-    about.addCredit(i18n("Maxmind"),
-                    i18n("Country locator for InfoWidget plugin. Flags are taken from http://flags.blogpotato.de/ so thanks to them too."),
-                    QString(),
-                    QStringLiteral("http://www.maxmind.com/"));
+    about.addCredit(
+        i18n("DB-IP.com"),
+        i18n("Provider of the IP-Country database used in the InfoWidget plugin. The data is licensed under the Creative Commons Attribution 4.0 International "
+             "License https://creativecommons.org/licenses/by/4.0/. Flags are taken from http://flags.blogpotato.de/ so thanks to them too."),
+        QString(),
+        QStringLiteral("https://db-ip.com/"));
+    about.addCredit(i18n("Maxmind"), i18n("The maxminddb library used for the InfoWidget plugin."), QString(), QStringLiteral("https://www.maxmind.com/"));
     about.addCredit(i18n("Adam Forsyth"), i18n("File prioritization and some other patches"), QStringLiteral("agforsyth@gmail.com"));
     about.addCredit(i18n("Thomas Bernard"),
                     i18n("Miniupnp was used as an example for our own UPnP implementation"),
@@ -169,10 +171,12 @@ int main(int argc, char **argv)
     about.addCredit(i18n("Andrius Štikonas"), i18n("KF5 porting"), QStringLiteral("andrius@stikonas.eu"));
     about.addCredit(i18n("Nick Shaforostoff"), i18n("KF5 porting"), QStringLiteral("shaforostoff@gmail.com"));
     about.addCredit(i18n("Alexander Trufanov"), i18n("Bugfixes, cleanups and optimizations"), QStringLiteral("trufanovan@gmail.com"));
+    about.addCredit(i18n("Jack Hill"), i18n("KF6 porting"), QStringLiteral("jackhill3103@gmail.com"));
 
     KAboutData::setApplicationData(about);
     about.setupCommandLine(&parser);
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("verbose"), i18n("Enable logging to standard output")));
+    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("enable-logging"), i18n("Enable logging")));
+    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("verbose"), i18n("Enable logging to standard output. Requires --enable-logging to be specified as well.")));
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("silent"), i18n("Silently open torrent given on URL")));
     parser.addPositionalArgument(QStringLiteral("+[URL]"), i18n("Document to open"));
     parser.process(app);
@@ -180,8 +184,8 @@ int main(int argc, char **argv)
 
     // config migration code
     auto config = KSharedConfig::openConfig();
-    if (!config->hasGroup("Plugins")) {
-        KConfigGroup pluginsGroup = config->group("Plugins");
+    if (!config->hasGroup(QStringLiteral("Plugins"))) {
+        KConfigGroup pluginsGroup = config->group(QStringLiteral("Plugins"));
         const QStringList groups = config->groupList();
         for (const QString &grpName : groups) {
             const QString entryName = grpName + QLatin1String("Enabled");
@@ -213,8 +217,11 @@ int main(int argc, char **argv)
         QObject::connect(&catcher, &bt::SignalCatcher::triggered, &app, &QApplication::quit);
 #endif
 
-        const bool logToStdout = parser.isSet(QStringLiteral("verbose"));
-        bt::InitLog(kt::DataDir(kt::CreateIfNotExists) + QLatin1String("log"), true, true, logToStdout);
+        const auto data_dir = kt::DataDir(kt::CreateIfNotExists);
+        if (parser.isSet(QStringLiteral("enable-logging"))) {
+            const bool logToStdout = parser.isSet(QStringLiteral("verbose"));
+            bt::InitLog(data_dir + QLatin1String("log"), true, true, logToStdout);
+        }
 
         kt::GUI widget;
 
